@@ -12,8 +12,10 @@ plot_fit <- function(object, level = 0.05, alpha = 0.33, ...){
     y_fit <- y_fit[sample(1:nrow(y_fit), size = nrow(y_fit), replace = TRUE, 
       prob = extract(object$stanfit, pars = "weights", permuted = TRUE)$weights),  , drop = FALSE]
   }
-  ppc_ribbon(y = as.numeric(object$y), 
-    yrep = y_fit,
-    x = as.numeric(time(object$y)), ...) + theme(legend.position = "none") + 
+  noNA <- which(!is.na(object$y))
+  ppc_ribbon(y = as.numeric(object$y[noNA]), 
+    yrep = y_fit[,noNA],
+    x = as.numeric(time(object$y))[noNA], ...) + 
+    theme(legend.position = "none") + 
     scale_x_continuous(name = "time")
 }
\ No newline at end of file
